@@ -19,7 +19,7 @@
 
 package jxl;
 
-import common.Assert;
+import jxl.common.Assert;
 
 import jxl.format.PageOrientation;
 import jxl.format.PaperSize;
