@@ -19,10 +19,11 @@
 
 package jxl;
 
+import java.io.File;
 import java.util.HashMap;
 import java.util.Locale;
 
-import common.Logger;
+import jxl.common.Logger;
 
 import jxl.biff.CountryCode;
 import jxl.biff.formula.FunctionNames;
@@ -127,6 +128,18 @@ public final class WorkbookSettings
    */
   private boolean autoFilterDisabled;
 
+  /**
+   * Flag to indicate whether a temporary file should be used when
+   * writing out the workbook
+   */
+  private boolean useTemporaryFileDuringWrite;
+
+  /**
+   * The directory for used for the temporary file during write.  If this
+   * is NULL, the default system directory is used
+   */
+  private File temporaryFileDuringWriteDirectory;
+
   /**
    * The locale.  Normally this is the same as the system locale, but there
    * may be cases (eg. where you are uploading many spreadsheets from foreign
@@ -170,13 +183,69 @@ public final class WorkbookSettings
    */
   private HashMap localeFunctionNames;
 
+  /**
+   * Flag to indicate whether all external data and pivot stuff should 
+   * refreshed
+   */
+  private boolean refreshAll;
+
+  /**
+   * Flag to indicate whether the file is a template or not (Usually with .xlt
+   * file name extension)
+   */
+  private boolean template;
+
+  /**
+   * Flag to indicate whether the file has been written by excel 2000.
+   *
+   * The EXCEL9FILE record indicates the file was written by Excel 2000. It has
+   * no record data field and is C0010000h. Any application other than Excel
+   * 2000 that edits the file should not write out this record.
+   *
+   * However, it seemas that excel 2003 + 2007 still set this flag....
+   */
+  private boolean excel9file= false;
+
+  /**
+   * The WINDOWPROTECT record stores an option from the Protect Workbook
+   * dialog box.
+   *
+   * =1 if the workbook windows are protected
+   */
+  private boolean windowProtected;
+
+  /**
+   * Write access user name.
+   * When not set (null) then we set it to  Java Excel API + Version number
+   */
+  private String writeAccess;
+
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab.
+   */
+  private int hideobj;
+
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab.
+   */
+  public final static int HIDEOBJ_HIDE_ALL= 2;
+
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab.
+   */
+  public final static int HIDEOBJ_SHOW_PLACEHOLDERS= 1;
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab.
+   */
+  public final static int HIDEOBJ_SHOW_ALL= 0;
+
   // **
   // The default values
   // **
   private static final int DEFAULT_INITIAL_FILE_SIZE = 5 * 1024 * 1024;
     // 5 megabytes
   private static final int DEFAULT_ARRAY_GROW_SIZE = 1024 * 1024; // 1 megabyte
-
+  
   /**
    * Default constructor
    */
@@ -187,6 +256,11 @@ public final class WorkbookSettings
     localeFunctionNames = new HashMap();
     excelDisplayLanguage = CountryCode.USA.getCode();
     excelRegionalSettings = CountryCode.UK.getCode();
+    refreshAll = false;
+    template = false;
+    excel9file = false;
+    windowProtected = false;
+    hideobj = HIDEOBJ_SHOW_ALL;
 
     // Initialize other properties from the system properties
     try
@@ -204,8 +278,18 @@ public final class WorkbookSettings
       propertySetsDisabled = Boolean.getBoolean("jxl.nopropertysets");
       ignoreBlankCells = Boolean.getBoolean("jxl.ignoreblanks");
       cellValidationDisabled = Boolean.getBoolean("jxl.nocellvalidation");
-      autoFilterDisabled = !Boolean.getBoolean("jxl.autofilter"); // autofilter currently disabled by default
+      autoFilterDisabled = !Boolean.getBoolean("jxl.autofilter"); 
+             // autofilter currently disabled by default
+      useTemporaryFileDuringWrite = 
+        Boolean.getBoolean("jxl.usetemporaryfileduringwrite");
+      String tempdir =
+        System.getProperty("jxl.temporaryfileduringwritedirectory");
 
+      if (tempdir != null)
+      {
+        temporaryFileDuringWriteDirectory = new File(tempdir);
+      }
+      
       encoding = System.getProperty("file.encoding");
     }
     catch (SecurityException e)
@@ -231,7 +315,7 @@ public final class WorkbookSettings
       {
         encoding = System.getProperty("jxl.encoding");
       }
-    }
+    } 
     catch (SecurityException e)
     {
       logger.warn("Error accessing system properties.", e);
@@ -631,4 +715,178 @@ public final class WorkbookSettings
   {
     autoFilterDisabled = disabled;
   }
+
+  /**
+   * Accessor for the temporary file during write.  If this is set, then
+   * when the workbook is written a temporary file will be used to store
+   * the interim binary data, otherwise it will take place in memory.  Setting
+   * this flag involves an assessment of the trade-offs between memory usage
+   * and performance
+   *
+   * @return TRUE if a temporary is file is used during writing, 
+   * FALSE otherwise
+   */
+  public boolean getUseTemporaryFileDuringWrite()
+  {
+    return useTemporaryFileDuringWrite;
+  }
+
+  /**
+   * Sets whether a temporary file is used during the generation of
+   * the workbook.  If not set, the workbook will take place entirely in
+   * memory.   Setting
+   * this flag involves an assessment of the trade-offs between memory usage
+   * and performance
+   *
+   * @return TRUE if a temporary is file is used during writing, 
+   * FALSE otherwise
+   */
+  public void setUseTemporaryFileDuringWrite(boolean temp)
+  {
+    useTemporaryFileDuringWrite = temp;
+  }
+
+  /**
+   * Used in conjunction with the UseTemporaryFileDuringWrite setting to
+   * set the target directory for the temporary files.   If this is not set,
+   * the system default temporary directory is used.
+   * This has no effect unless the useTemporaryFileDuringWrite setting
+   * is TRUE
+   *
+   * @param dir the directory to which temporary files should be written
+   */
+  public void setTemporaryFileDuringWriteDirectory(File dir)
+  {
+    temporaryFileDuringWriteDirectory = dir;
+  }
+
+  /**
+   * Used in conjunction with the UseTemporaryFileDuringWrite setting to
+   * set the target directory for the temporary files.  This value can 
+   * be NULL, in which case the normal system default temporary directory
+   * is used instead
+   *
+   * @return the temporary directory used during write, or NULL if it is 
+   *         not set
+   */
+  public File getTemporaryFileDuringWriteDirectory()
+  {
+    return temporaryFileDuringWriteDirectory;
+  }
+
+
+  /**
+   * When true then Refresh All should be done on all external data ranges and
+   * PivotTables when loading the workbook (the default is =0)
+   *
+   * @param refreshAll the refreshAll to set
+   */
+  public void setRefreshAll(boolean refreshAll)
+  {
+    this.refreshAll = refreshAll;
+  }
+
+  /**
+   * When true then Refresh All should be done on all external data ranges and
+   * PivotTables when loading the workbook (the default is =0)
+   *
+   * @return the refreshAll value
+   */
+  public boolean getRefreshAll()
+  {
+    return refreshAll;
+  }
+
+  /**
+   * Workbook Is a Template
+   * @return the template
+   */
+  public boolean getTemplate()
+  {
+    return template;
+  }
+
+  /**
+   * Workbook Is a Template
+   * @param template the template to set
+   */
+  public void setTemplate(boolean template)
+  {
+    this.template = template;
+  }
+
+  /**
+   * Has this file been written by excel 2000?
+   * 
+   * @return the excel9file
+   */
+  public boolean getExcel9File()
+  {
+    return excel9file;
+  }
+
+  /**
+   * @param excel9file the excel9file to set
+   */
+  public void setExcel9File(boolean excel9file)
+  {
+    this.excel9file = excel9file;
+  }
+
+  /**
+   * @return the windowprotected
+   */
+  public boolean getWindowProtected()
+  {
+    return windowProtected;
+  }
+
+  /**
+   * @param windowprotected the windowprotected to set
+   */
+  public void setWindowProtected(boolean windowprotected)
+  {
+    this.windowProtected = windowProtected;
+  }
+
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab
+   *
+   * Possible values are:
+   * HIDEOBJ_HIDE_ALL, HIDEOBJ_SHOW_ALL and HIDEOBJ_SHOW_PLACEHOLDERS
+   * @return the hideobj
+   */
+  public int getHideobj()
+  {
+    return hideobj;
+  }
+
+  /**
+   * The HIDEOBJ record stores options selected in the Options dialog,View tab
+   *
+   * Possible values are:
+   * HIDEOBJ_HIDE_ALL, HIDEOBJ_SHOW_ALL and HIDEOBJ_SHOW_PLACEHOLDERS
+   * @param hideobj the hideobj to set
+   */
+  public void setHideobj(int hideobj)
+  {
+    this.hideobj = hideobj;
+  }
+
+  /**
+   * @return the writeAccess
+   */
+  public String getWriteAccess()
+  {
+    return writeAccess;
+  }
+
+  /**
+   * @param writeAccess the writeAccess to set
+   */
+  public void setWriteAccess(String writeAccess)
+  {
+    this.writeAccess = writeAccess;
+  }
 }
+
