@@ -24,6 +24,8 @@ import java.util.Collection;
 import jxl.common.Assert;
 import jxl.common.Logger;
 
+import jxl.CellReferenceHelper;
+import jxl.Range;
 import jxl.biff.drawing.ComboBox;
 import jxl.biff.drawing.Comment;
 import jxl.write.biff.CellValue;
@@ -268,16 +270,49 @@ public class BaseCellFeatures
   }
 
   /**
-   * Removes any data validation, if present
+   * Public function which removes any data validation, if present
    */
   public void removeDataValidation()
   {
-    // Remove the validation from the WritableSheet object if present
-    if (dataValidation)
+    if (!dataValidation)
     {
-      writableCell.removeDataValidation();
+      return;
     }
 
+    // If the data validation is shared, then generate a warning
+    DVParser dvp = getDVParser();
+    if (dvp.extendedCellsValidation())
+    {
+      logger.warn("Cannot remove data validation from " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of the shared reference " +
+                  CellReferenceHelper.getCellReference(dvp.getFirstColumn(),
+                                                       dvp.getFirstRow()) +
+                  "-" +
+                  CellReferenceHelper.getCellReference(dvp.getLastColumn(),
+                                                       dvp.getLastRow()));
+      return;
+    }
+
+    // Remove the validation from the WritableSheet object if present
+    writableCell.removeDataValidation();
+    clearValidationSettings();
+  }
+
+  /**
+   * Internal function which removes any data validation, including
+   * shared ones, if present.  This is called from WritableSheetImpl
+   * in response to a call to removeDataValidation
+   */
+  public void removeSharedDataValidation()
+  {
+    if (!dataValidation)
+    {
+      return;
+    }
+
+    // Remove the validation from the WritableSheet object if present
+    writableCell.removeDataValidation();
     clearValidationSettings();
   }
 
@@ -321,6 +356,13 @@ public class BaseCellFeatures
    */
   public void setDataValidationList(Collection c)
   {
+    if (dataValidation && getDVParser().extendedCellsValidation())
+    {
+      logger.warn("Cannot set data validation on " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of a shared data validation");
+      return;
+    }
     clearValidationSettings();
     dvParser = new DVParser(c);
     dropDown = true;
@@ -334,6 +376,13 @@ public class BaseCellFeatures
    */
   public void setDataValidationRange(int col1, int r1, int col2, int r2)
   {
+    if (dataValidation && getDVParser().extendedCellsValidation())
+    {
+      logger.warn("Cannot set data validation on " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of a shared data validation");
+      return;
+    }
     clearValidationSettings();
     dvParser = new DVParser(col1, r1, col2, r2);
     dropDown = true;
@@ -345,14 +394,31 @@ public class BaseCellFeatures
    */
   public void setDataValidationRange(String namedRange)
   {
+    if (dataValidation && getDVParser().extendedCellsValidation())
+    {
+      logger.warn("Cannot set data validation on " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of a shared data validation");
+      return;
+    }
     clearValidationSettings();
     dvParser = new DVParser(namedRange);
     dropDown = true;
     dataValidation = true;
   }
 
+  /**
+   * Sets the data validation based upon a numerical condition
+   */
   public void setNumberValidation(double val, ValidationCondition c)
   {
+    if (dataValidation && getDVParser().extendedCellsValidation())
+    {
+      logger.warn("Cannot set data validation on " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of a shared data validation");
+      return;
+    }
     clearValidationSettings();
     dvParser = new DVParser(val, Double.NaN, c.getCondition());
     dropDown = false;
@@ -362,6 +428,13 @@ public class BaseCellFeatures
   public void setNumberValidation(double val1, double val2, 
                                   ValidationCondition c)
   {
+    if (dataValidation && getDVParser().extendedCellsValidation())
+    {
+      logger.warn("Cannot set data validation on " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " as it is part of a shared data validation");
+      return;
+    }
     clearValidationSettings();
     dvParser = new DVParser(val1, val2, c.getCondition());
     dropDown = false;
@@ -431,4 +504,50 @@ public class BaseCellFeatures
 
     return null; // keep the compiler happy
   }
+
+  /**
+   * Use the same data validation logic as the specified cell features
+   *
+   * @param cf the data validation to reuse
+   */
+  public void shareDataValidation(BaseCellFeatures source)
+  {
+    if (dataValidation)
+    {
+      logger.warn("Attempting to share a data validation on cell " + 
+                  CellReferenceHelper.getCellReference(writableCell) + 
+                  " which already has a data validation");
+      return;
+    }
+    clearValidationSettings();
+    dvParser = source.getDVParser();
+    validationSettings = null;
+    dataValidation = true;
+    dropDown = source.dropDown;
+    comboBox = source.comboBox;
+  }
+
+  /**
+   * Gets the range of cells to which the data validation applies.  If the
+   * validation applies to just this cell, this will be reflected in the 
+   * returned range
+   *
+   * @return the range to which the same validation extends, or NULL if this
+   *         cell doesn't have a validation
+   */
+  public Range getSharedDataValidationRange()
+  {
+    if (!dataValidation)
+    {
+      return null;
+    }
+    
+    DVParser dvp = getDVParser();
+
+    return new SheetRangeImpl(writableCell.getSheet(),
+                              dvp.getFirstColumn(),
+                              dvp.getFirstRow(),
+                              dvp.getLastColumn(),
+                              dvp.getLastRow());
+  }
 }
