@@ -24,7 +24,7 @@ import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.text.SimpleDateFormat;
 
-import common.Logger;
+import jxl.common.Logger;
 
 import jxl.WorkbookSettings;
 import jxl.format.Format;
