@@ -22,10 +22,10 @@ package jxl.biff.drawing;
 import java.io.FileInputStream;
 import java.io.IOException;
 
-import common.Assert;
-import common.Logger;
-import common.LengthUnit;
-import common.LengthConverter;
+import jxl.common.Assert;
+import jxl.common.Logger;
+import jxl.common.LengthUnit;
+import jxl.common.LengthConverter;
 
 import jxl.Image;
 import jxl.Sheet;
