@@ -19,7 +19,7 @@
 
 package jxl.biff.drawing;
 
-import common.Logger;
+import jxl.common.Logger;
 
 /**
  * An Spgr container record in an escher stream
