@@ -80,6 +80,11 @@ class TokenFormulaParser implements Parser
    */
   private WorkbookSettings settings;
 
+  /**
+   * The parse context
+   */
+  private ParseContext parseContext;
+
   /**
    * Constructor
    */
@@ -87,7 +92,8 @@ class TokenFormulaParser implements Parser
                             Cell c, 
                             ExternalSheet es, 
                             WorkbookMethods nt,
-                            WorkbookSettings ws)
+                            WorkbookSettings ws,
+                            ParseContext pc)
   {
     tokenData = data;
     pos = 0;
@@ -96,6 +102,7 @@ class TokenFormulaParser implements Parser
     nameTable = nt;
     tokenStack = new Stack();
     settings = ws;
+    parseContext = pc;
     
     Assert.verify(nameTable != null);
   }
@@ -206,12 +213,14 @@ class TokenFormulaParser implements Parser
       {
         Name n = new Name();
         pos += n.read(tokenData, pos);
+        n.setParseContext(parseContext);
         tokenStack.push(n);
       }
       else if (t == Token.NAMED_RANGE)
       {
         NameRange nr = new NameRange(nameTable);
         pos += nr.read(tokenData, pos);
+        nr.setParseContext(parseContext);
         tokenStack.push(nr);
       }
       else if (t == Token.INTEGER)
