@@ -1228,6 +1228,34 @@ public class Write
     // Set the row grouping
     s1.setRowGroup(39, 45, false);
     // s1.setRowGroup(72, 74, true);
+
+    l = new Label(0, 66, "Block of cells B67-F71 with data validation");
+    s1.addCell(l);
+
+    al = new ArrayList();
+    al.add("Achilles");
+    al.add("Agamemnon");
+    al.add("Hector");
+    al.add("Odysseus");
+    al.add("Patroclus");
+    al.add("Nestor");
+
+    b = new Blank(1, 66);
+    cellFeatures = new WritableCellFeatures();
+    cellFeatures.setDataValidationList(al);
+    b.setCellFeatures(cellFeatures);
+    s1.addCell(b);
+    s1.applySharedDataValidation(b, 4,4);
+
+    cellFeatures = new WritableCellFeatures();
+    cellFeatures.setDataValidationRange("");
+    l = new Label(0, 71, "Read only cell using empty data validation");
+    l.setCellFeatures(cellFeatures);
+    s1.addCell(l);
+
+    // Set the row grouping
+    s1.setRowGroup(39, 45, false);
+    // s1.setRowGroup(72, 74, true);
   }
 
   /**
