@@ -21,8 +21,8 @@ package jxl.read.biff;
 
 import java.util.ArrayList;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.WorkbookSettings;
 import jxl.biff.BuiltInName;
