@@ -21,9 +21,10 @@ package jxl.read.biff;
 
 import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.regex.Pattern;
 
-import common.Logger;
-import common.Assert;
+import jxl.common.Logger;
+import jxl.common.Assert;
 
 import jxl.Cell;
 import jxl.CellType;
@@ -37,6 +38,7 @@ import jxl.SheetSettings;
 import jxl.WorkbookSettings;
 import jxl.biff.BuiltInName;
 import jxl.biff.AutoFilter;
+import jxl.biff.CellFinder;
 import jxl.biff.CellReferenceHelper;
 import jxl.biff.ConditionalFormat;
 import jxl.biff.DataValidation;
@@ -373,23 +375,68 @@ public class SheetImpl implements Sheet
    */
   public Cell findCell(String contents)
   {
-    Cell cell = null;
-    boolean found = false;
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(contents);
+  }
 
-    for (int i = 0; i < getRows() && !found; i++)
-    {
-      Cell[] row = getRow(i);
-      for (int j = 0; j < row.length && !found; j++)
-      {
-        if (row[j].getContents().equals(contents))
-        {
-          cell = row[j];
-          found = true;
-        }
-      }
-    }
+  /**
+   * Gets the cell whose contents match the string passed in.
+   * If no match is found, then null is returned.  The search is performed
+   * on a row by row basis, so the lower the row number, the more
+   * efficiently the algorithm will perform
+   * 
+   * @param contents the string to match
+   * @param firstCol the first column within the range
+   * @param firstRow the first row of the range
+   * @param lastCol the last column within the range
+   * @param lastRow the last row within the range
+   * @param reverse indicates whether to perform a reverse search or not
+   * @return the Cell whose contents match the parameter, null if not found
+   */
+  public Cell findCell(String contents, 
+                       int firstCol, 
+                       int firstRow, 
+                       int lastCol, 
+                       int lastRow, 
+                       boolean reverse)
+  {
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(contents,
+                               firstCol, 
+                               firstRow, 
+                               lastCol,
+                               lastRow, 
+                               reverse);
+  }
 
-    return cell;
+  /**
+   * Gets the cell whose contents match the regular expressionstring passed in.
+   * If no match is found, then null is returned.  The search is performed
+   * on a row by row basis, so the lower the row number, the more
+   * efficiently the algorithm will perform
+   * 
+   * @param pattern the regular expression string to match
+   * @param firstCol the first column within the range
+   * @param firstRow the first row of the range
+   * @param lastRow the last row within the range
+   * @param lastCol the last column within the ranage
+   * @param reverse indicates whether to perform a reverse search or not
+   * @return the Cell whose contents match the parameter, null if not found
+   */
+  public Cell findCell(Pattern pattern, 
+                       int firstCol, 
+                       int firstRow, 
+                       int lastCol, 
+                       int lastRow, 
+                       boolean reverse)
+  {
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findCell(pattern,
+                               firstCol, 
+                               firstRow, 
+                               lastCol,
+                               lastRow, 
+                               reverse);
   }
 
   /**
@@ -406,25 +453,8 @@ public class SheetImpl implements Sheet
    */
   public LabelCell findLabelCell(String contents)
   {
-    LabelCell cell = null;
-    boolean found = false;
-
-    for (int i = 0; i < getRows() && !found; i++)
-    {
-      Cell[] row = getRow(i);
-      for (int j = 0; j < row.length && !found; j++)
-      {
-        if ((row[j].getType() == CellType.LABEL ||
-             row[j].getType() == CellType.STRING_FORMULA) &&
-            row[j].getContents().equals(contents))
-        {
-          cell = (LabelCell) row[j];
-          found = true;
-        }
-      }
-    }
-
-    return cell;
+    CellFinder cellFinder = new CellFinder(this);
+    return cellFinder.findLabelCell(contents);
   }
 
   /**
