@@ -308,7 +308,7 @@ final class SheetReader
         CellReferenceHelper.getCellReference
           (cell.getColumn(), cell.getRow(), sb);
         logger.warn("Cell " + sb.toString() +
-                      " already contains data");
+                    " already contains data");
       }
       cells[cell.getRow()][cell.getColumn()] = cell;
     }
@@ -316,11 +316,11 @@ final class SheetReader
     {
       outOfBoundsCells.add(cell);
       /*
-      logger.warn("Cell " +
-                  CellReferenceHelper.getCellReference
-                                   (cell.getColumn(), cell.getRow()) +
-                  " exceeds defined cell boundaries in Dimension record " +
-                  "(" + numCols + "x" + numRows + ")");
+        logger.warn("Cell " +
+        CellReferenceHelper.getCellReference
+        (cell.getColumn(), cell.getRow()) +
+        " exceeds defined cell boundaries in Dimension record " +
+        "(" + numCols + "x" + numRows + ")");
       */
     }
   }
@@ -961,6 +961,12 @@ final class SheetReader
       else if (type == Type.PLS)
       {
         plsRecord = new PLSRecord(r);
+
+        // Check for Continue records
+        while (excelFile.peek().getType() == Type.CONTINUE)
+        {
+          r.addContinueRecord(excelFile.next());
+        }
       }
       else if (type == Type.DVAL)
       {
@@ -1550,9 +1556,6 @@ final class SheetReader
 
         if (c == null)
         {
-          logger.warn("Cell at " + 
-                      CellReferenceHelper.getCellReference(col, row) +
-                      " not present - adding a blank");
           MulBlankCell mbc = new MulBlankCell(row,
                                               col,
                                               0,
@@ -1562,12 +1565,9 @@ final class SheetReader
           cf.setValidationSettings(dvsr);
           mbc.setCellFeatures(cf);
           addCell(mbc);
-
-          return;
         }
-
-        if (c instanceof CellFeaturesAccessor)
-        {
+        else if (c instanceof CellFeaturesAccessor)
+        {          // Check to see if the cell already contains a comment
           CellFeaturesAccessor cv = (CellFeaturesAccessor) c;
           CellFeatures cf = cv.getCellFeatures();
 
@@ -1751,12 +1751,16 @@ final class SheetReader
                                    workbookSettings);
 
         Record r2 = excelFile.next();
-        if (r2.getType() == Type.MSODRAWING)
+        Assert.verify(r2.getType() == Type.MSODRAWING || 
+                      r2.getType() == Type.CONTINUE);
+        if (r2.getType() == Type.MSODRAWING || 
+            r2.getType() == Type.CONTINUE)
         {
           MsoDrawingRecord mso = new MsoDrawingRecord(r2);
           button.addMso(mso);
           r2 = excelFile.next();
         }
+
         Assert.verify(r2.getType() == Type.TXO);
         TextObjectRecord txo = new TextObjectRecord(r2);
         button.setTextObject(txo);
@@ -1778,13 +1782,51 @@ final class SheetReader
         return;
       }
 
-      // Handle other types
-      if (objRecord.getType() != ObjRecord.CHART)
+      // Non-supported types which have multiple record types
+      if (objRecord.getType() == ObjRecord.TEXT)
       {
-        logger.warn(objRecord.getType() + " on sheet \"" +
+        logger.warn(objRecord.getType() + " Object on sheet \"" +
                     sheet.getName() +
                     "\" not supported - omitting");
 
+        // Still need to add the drawing data to preserve the hierarchy
+        if (drawingData == null)
+        {
+          drawingData = new DrawingData();
+
+        }
+        drawingData.addData(msoRecord.getData());
+
+        Record r2 = excelFile.next();
+        Assert.verify(r2.getType() == Type.MSODRAWING || 
+                      r2.getType() == Type.CONTINUE);
+        if (r2.getType() == Type.MSODRAWING || 
+            r2.getType() == Type.CONTINUE)
+        {
+          MsoDrawingRecord mso = new MsoDrawingRecord(r2);
+          drawingData.addRawData(mso.getData());
+          r2 = excelFile.next();
+        }
+
+        Assert.verify(r2.getType() == Type.TXO);
+
+        if (workbook.getDrawingGroup() != null) // can be null for Excel 95
+        {
+          workbook.getDrawingGroup().setDrawingsOmitted(msoRecord,
+                                                        objRecord);
+        }
+
+        return;
+      }
+
+      // Handle other types
+      if (objRecord.getType() != ObjRecord.CHART)
+      {
+        logger.warn(objRecord.getType() + " Object on sheet \"" +
+                    sheet.getName() +
+                    "\" not supported - omitting");
+
+        // Still need to add the drawing data to preserve the hierarchy
         if (drawingData == null)
         {
           drawingData = new DrawingData();
@@ -1833,11 +1875,11 @@ final class SheetReader
       resizedRows = Math.max(resizedRows, cell.getRow() + 1);
       resizedCols = Math.max(resizedCols, cell.getColumn() + 1);
     }
-
-    logger.warn("Some cells exceeded the specified bounds.  Resizing " + 
-                "sheet dimensions from " + 
-                numCols + "x"+numRows + " to " + 
-                resizedCols + "x" + resizedRows);
+    
+    // There used to be a warning here about exceeding the sheet dimensions,
+    // but removed it when I added the ability to perform data validation
+    // on entire rows or columns - in which case it would blow out any
+    // existing dimensions
 
     // Resize the columns, if necessary
     if (resizedCols > numCols)
