@@ -404,6 +404,28 @@ public interface WritableSheet extends Sheet
    * @param wi the image to remove
    */
   public void removeImage(WritableImage wi);
+
+  /**
+   * Extend the data validation contained in the specified cell across and 
+   * downwards.
+   * NOTE:  The source cell (top left) must have been added to the sheet prior
+   * to this method being called
+   *
+   * @param col the number of cells accross to apply this data validation
+   * @param row the number of cells downwards to apply this data validation
+   */
+  public void applySharedDataValidation(WritableCell cell, int col, int row) 
+    throws WriteException;
+
+  /**
+   * Remove the shared data validation from multiple cells.  The cell passed 
+   * in is the top left cell.  The data validation is removed from this 
+   * cell and all cells which share the same validation.
+   *
+   * @param cell the top left cell containing the shared data validation
+   */
+  public void removeSharedDataValidation(WritableCell cell)
+    throws WriteException;
 }
 
 
