@@ -24,9 +24,11 @@ import jxl.common.Logger;
 
 import jxl.Cell;
 import jxl.CellFeatures;
+import jxl.CellReferenceHelper;
 import jxl.Sheet;
 import jxl.biff.DataValidation;
 import jxl.biff.DataValiditySettingsRecord;
+import jxl.biff.DVParser;
 import jxl.biff.FormattingRecords;
 import jxl.biff.IntegerHelper;
 import jxl.biff.NumFormatRecordsException;
@@ -448,7 +450,7 @@ public abstract class CellValue extends WritableRecordData
    *
    * @return the sheet containing this cell
    */
-  protected WritableSheetImpl getSheet()
+  public WritableSheetImpl getSheet()
   {
     return sheet;
   }
@@ -509,7 +511,27 @@ public abstract class CellValue extends WritableRecordData
   {
     if (features != null) 
     {
-      logger.warn("current cell features not null - overwriting");
+      logger.warn("current cell features for " + 
+                  CellReferenceHelper.getCellReference(this) + 
+                  " not null - overwriting");
+
+      // Check to see if the features include a shared data validation
+      if (features.hasDataValidation() &&
+          features.getDVParser() != null &&
+          features.getDVParser().extendedCellsValidation())
+      {
+        DVParser dvp = features.getDVParser();
+        logger.warn("Cannot add cell features to " + 
+                    CellReferenceHelper.getCellReference(this) + 
+                    " because it is part of the shared cell validation " +
+                    "group " +
+                    CellReferenceHelper.getCellReference(dvp.getFirstColumn(),
+                                                         dvp.getFirstRow()) +
+                    "-" +
+                    CellReferenceHelper.getCellReference(dvp.getLastColumn(),
+                                                         dvp.getLastRow()));
+        return;
+      }
     }
 
     features = cf;
@@ -566,9 +588,9 @@ public abstract class CellValue extends WritableRecordData
       }
       catch (jxl.biff.formula.FormulaException e)
       {
-        e.printStackTrace();
         Assert.verify(false);
       }
+
       sheet.addValidationCell(this);
       if (!features.hasDropDown())
       {
@@ -578,6 +600,9 @@ public abstract class CellValue extends WritableRecordData
       // Get the combo box drawing object for list validations
       if (sheet.getComboBox() == null)
       {
+        // Need to add the combo box the first time, since even though
+        // it doesn't need a separate Sp entry, it still needs to increment
+        // the shape id
         ComboBox cb = new ComboBox();
         sheet.addDrawing(cb);
         sheet.getWorkbook().addDrawing(cb);
@@ -589,21 +614,20 @@ public abstract class CellValue extends WritableRecordData
   }
 
   /**
-   * Removes the cell features from the Workbook/Worksheet.  Called when
-   * a cell is being removed/replaced from a worksheet
+   * Internal function invoked by WritableSheetImpl called when shared data 
+   * validation is removed
    */
   public final void removeCellFeatures()
   {
-    if (features == null)
-    {
-      return;
-    }
-
+    /*
     // Remove the comment
     features.removeComment();
 
     // Remove the data validation
     features.removeDataValidation();
+    */
+
+    features = null;
   }
 
 
