@@ -24,8 +24,8 @@ import java.net.URL;
 import java.net.MalformedURLException;
 import java.util.ArrayList;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.CellType;
 import jxl.Hyperlink;
@@ -44,8 +44,7 @@ import jxl.write.WritableSheet;
 
 
 /**
- * A number record.  This is stored as 8 bytes, as opposed to the 
- * 4 byte RK record
+ * A hyperlink
  */
 public class HyperlinkRecord extends WritableRecordData
 {
@@ -447,7 +446,7 @@ public class HyperlinkRecord extends WritableRecordData
       return data;
     }
 
-    // Build up the common data
+    // Build up the jxl.common.data
     byte[] commonData = new byte[32];
 
     // Set the range of cells this hyperlink applies to
@@ -492,9 +491,9 @@ public class HyperlinkRecord extends WritableRecordData
     }
     else if (isFile())
     {
-      optionFlags = 3;
+      optionFlags = 1;
 
-      if (contents == null)
+      if (contents != null)
       {
         optionFlags |= 0x14;
       }
@@ -882,7 +881,7 @@ public class HyperlinkRecord extends WritableRecordData
   /**
    * Gets the hyperlink stream specific to a URL link
    *
-   * @param cd the data common for all types of hyperlink
+   * @param cd the data jxl.common.for all types of hyperlink
    * @return the raw data for a URL hyperlink
    */
   private byte[] getURLData(byte[] cd)
@@ -939,7 +938,7 @@ public class HyperlinkRecord extends WritableRecordData
   /**
    * Gets the hyperlink stream specific to a URL link
    *
-   * @param cd the data common for all types of hyperlink
+   * @param cd the data jxl.common.for all types of hyperlink
    * @return the raw data for a URL hyperlink
    */
   private byte[] getUNCData(byte[] cd)
@@ -964,7 +963,7 @@ public class HyperlinkRecord extends WritableRecordData
   /**
    * Gets the hyperlink stream specific to a local file link
    *
-   * @param cd the data common for all types of hyperlink
+   * @param cd the data jxl.common.for all types of hyperlink
    * @return the raw data for a URL hyperlink
    */
   private byte[] getFileData(byte[] cd)
@@ -1038,25 +1037,26 @@ public class HyperlinkRecord extends WritableRecordData
     String shortFilePath = shortFilePathSB.toString();
 
     int dataLength = cd.length + 
-                     4 + (shortFilePath.length() + 1) * 2 + // short file name
+                     4 + (shortFilePath.length() + 1) + // short file name
                      16 + // inexplicable byte sequence
                      2 + // up directory level count
-                     4 + filePath.length() + 1 + // long file name
-                     4 + // inexplicable byte sequence
-                     24; // don't ask
+                     8 + (filePath.length() + 1) * 2 + // long file name
+                     24; // inexplicable byte sequence
+
 
     if (contents != null)
     {
       dataLength += 4 + (contents.length() + 1) * 2;
     }
 
-    // Copy across the common data into the new array
+    // Copy across the jxl.common.data into the new array
     byte[] d = new byte[dataLength];
 
     System.arraycopy(cd, 0, d, 0, cd.length);
     
     int filePos = cd.length;
-
+    
+    // Add in the description text
     if (contents != null)
     {
       IntegerHelper.getFourBytes(contents.length() + 1, d, filePos);
@@ -1066,14 +1066,6 @@ public class HyperlinkRecord extends WritableRecordData
 
     int curPos = filePos;
 
-    // The number of bytes in the short file name, including zero terminator
-    IntegerHelper.getFourBytes((shortFilePath.length() + 1), d, curPos);
-
-    // The short file name
-    StringHelper.getUnicodeBytes(shortFilePath, d, curPos+4);
-
-    curPos += 4 + (shortFilePath.length() + 1) * 2;
-
     // Inexplicable byte sequence
     d[curPos]    = (byte) 0x03;
     d[curPos+1]  = (byte) 0x03;
@@ -1098,20 +1090,63 @@ public class HyperlinkRecord extends WritableRecordData
     IntegerHelper.getTwoBytes(upLevelCount, d, curPos);
     curPos += 2;
 
-    // The number of characters in the short file name
-    // including zero terminator
-    IntegerHelper.getFourBytes((filePath.length() + 1), d, curPos);
-    curPos += 4;
+    // The number of bytes in the short file name, including zero terminator
+    IntegerHelper.getFourBytes((shortFilePath.length() + 1), d, curPos);
+
+    // The short file name
+    StringHelper.getBytes(shortFilePath, d, curPos+4);
+
+    curPos += 4 + (shortFilePath.length() + 1);
 
-    // The long file name
-    StringHelper.getBytes(filePath, d, curPos);
-    curPos += (filePath.length() + 1);
-    
     // Inexplicable byte sequence
     d[curPos]   = (byte) 0xff;
     d[curPos+1] = (byte) 0xff;
     d[curPos+2] = (byte) 0xad;
     d[curPos+3] = (byte) 0xde;
+    d[curPos+4] = (byte) 0x0;
+    d[curPos+5] = (byte) 0x0;
+    d[curPos+6] = (byte) 0x0;
+    d[curPos+7] = (byte) 0x0;
+    d[curPos+8] = (byte) 0x0;
+    d[curPos+9] = (byte) 0x0;
+    d[curPos+10] = (byte) 0x0;
+    d[curPos+11] = (byte) 0x0;
+    d[curPos+12] = (byte) 0x0;
+    d[curPos+13] = (byte) 0x0;
+    d[curPos+14] = (byte) 0x0;
+    d[curPos+15] = (byte) 0x0;
+    d[curPos+16] = (byte) 0x0;
+    d[curPos+17] = (byte) 0x0;
+    d[curPos+18] = (byte) 0x0;
+    d[curPos+19] = (byte) 0x0;
+    d[curPos+20] = (byte) 0x0;
+    d[curPos+21] = (byte) 0x0;
+    d[curPos+22] = (byte) 0x0;
+    d[curPos+23] = (byte) 0x0;
+
+    curPos += 24;
+
+    // Size of the long file name data in bytes, including inexplicable data 
+    // fields
+    int size = 6 + filePath.length() * 2;
+    IntegerHelper.getFourBytes(size, d, curPos);
+    curPos += 4;
+
+    // The number of bytes in the long file name
+    // NOT including zero terminator
+    IntegerHelper.getFourBytes((filePath.length()) * 2, d, curPos);
+    curPos += 4;
+
+    // Inexplicable bytes
+    d[curPos] = (byte) 0x3;
+    d[curPos+1] = (byte) 0x0;
+    
+    curPos += 2;
+
+    // The long file name
+    StringHelper.getUnicodeBytes(filePath, d, curPos);
+    curPos += (filePath.length() + 1) * 2;
+    
 
     /*
     curPos += 24;
@@ -1159,7 +1194,7 @@ public class HyperlinkRecord extends WritableRecordData
 
     if (prefix.length() > 8)
     {
-      prefix = prefix.substring(0, 6) + "~" + (prefix.length() - 6);
+      prefix = prefix.substring(0, 6) + "~" + (prefix.length() - 8);
       prefix = prefix.substring(0, 8);
     }
 
@@ -1178,7 +1213,7 @@ public class HyperlinkRecord extends WritableRecordData
   /**
    * Gets the hyperlink stream specific to a location link
    *
-   * @param cd the data common for all types of hyperlink
+   * @param cd the data jxl.common.for all types of hyperlink
    * @return the raw data for a URL hyperlink
    */
   private byte[] getLocationData(byte[] cd)
