@@ -19,7 +19,7 @@
 
 package jxl.write.biff;
 
-import common.Logger;
+import jxl.common.Logger;
 
 import jxl.biff.BuiltInName;
 import jxl.biff.IntegerHelper;
@@ -469,13 +469,13 @@ class NameRecord extends WritableRecordData
    */
   void rowInserted(int sheetIndex, int row)
   {
-    if (sheetIndex != sheetRef)
-    {
-      return;
-    }
-
     for (int i = 0 ; i < ranges.length ; i++)
     {
+      if (sheetIndex != ranges[i].getExternalSheet())
+      {
+        continue; // shame on me - this is no better than a goto
+      }
+
       if (row <= ranges[i].getFirstRow())
       {
         ranges[i].incrementFirstRow();
@@ -499,13 +499,13 @@ class NameRecord extends WritableRecordData
    */
   boolean rowRemoved(int sheetIndex, int row)
   {
-    if (sheetIndex != sheetRef)
-    {
-      return false;
-    }
-
     for (int i = 0 ; i < ranges.length ; i++)
     {
+      if (sheetIndex != ranges[i].getExternalSheet())
+      {
+        continue; // shame on me - this is no better than a goto
+      }
+
       if (row == ranges[i].getFirstRow() && row == ranges[i].getLastRow())
       {
         // remove the range
@@ -564,13 +564,13 @@ class NameRecord extends WritableRecordData
    */
   boolean columnRemoved(int sheetIndex, int col)
   {
-    if (sheetIndex != sheetRef)
-    {
-      return false;
-    }
-
     for (int i = 0 ; i < ranges.length ; i++)
     {
+      if (sheetIndex != ranges[i].getExternalSheet())
+      {
+        continue; // shame on me - this is no better than a goto
+      }
+
       if (col == ranges[i].getFirstColumn() && col == 
           ranges[i].getLastColumn())
       {
@@ -630,13 +630,13 @@ class NameRecord extends WritableRecordData
    */
   void columnInserted(int sheetIndex, int col)
   {
-    if (sheetIndex != sheetRef)
-    {
-      return;
-    }
-
     for (int i = 0 ; i < ranges.length ; i++)
     {
+      if (sheetIndex != ranges[i].getExternalSheet())
+      {
+        continue; // shame on me - this is no better than a goto
+      }
+
       if (col <= ranges[i].getFirstColumn())
       {
         ranges[i].incrementFirstColumn();
