@@ -19,8 +19,8 @@
 
 package jxl.write.biff;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.CellReferenceHelper;
 import jxl.CellType;
