@@ -101,6 +101,7 @@ class SheetCopier
   private ArrayList drawings;
   private ArrayList images;
   private ArrayList conditionalFormats;
+  private ArrayList validatedCells;
   private AutoFilter autoFilter;
   private DataValidation dataValidation;
   private ComboBox comboBox;
@@ -174,6 +175,11 @@ class SheetCopier
     conditionalFormats = cf;
   }
 
+  void setValidatedCells(ArrayList vc)
+  {
+    validatedCells = vc;
+  }
+
   AutoFilter getAutoFilter()
   {
     return autoFilter;
@@ -362,6 +368,7 @@ class SheetCopier
                                           toSheet.getWorkbook(),
                                           workbookSettings);
       int objid = dataValidation.getComboBoxObjectId();
+
       if (objid != 0)
       {
         comboBox = (ComboBox) drawings.get(objid);
@@ -936,6 +943,14 @@ class SheetCopier
           if (c != null)
           {
             toSheet.addCell(c);
+
+            // Cell.setCellFeatures short circuits when the cell is copied,
+            // so make sure the copy logic handles the validated cells        
+            if (c.getCellFeatures() != null &&
+                c.getCellFeatures().hasDataValidation())
+            {
+              validatedCells.add(c);
+            }
           }
         }
         catch (WriteException e)
@@ -975,6 +990,14 @@ class SheetCopier
           if (c != null)
           {
             toSheet.addCell(c);
+
+            // Cell.setCellFeatures short circuits when the cell is copied,
+            // so make sure the copy logic handles the validated cells
+            if (c.getCellFeatures() != null &
+                c.getCellFeatures().hasDataValidation())
+            {
+              validatedCells.add(c);
+            }
           }
         }
         catch (WriteException e)
