@@ -32,6 +32,7 @@ import jxl.common.Logger;
 import jxl.BooleanCell;
 import jxl.Cell;
 import jxl.CellFeatures;
+import jxl.CellReferenceHelper;
 import jxl.CellType;
 import jxl.CellView;
 import jxl.DateCell;
@@ -47,9 +48,9 @@ import jxl.WorkbookSettings;
 import jxl.biff.AutoFilter;
 import jxl.biff.BuiltInName;
 import jxl.biff.CellFinder;
-import jxl.biff.CellReferenceHelper;
 import jxl.biff.ConditionalFormat;
 import jxl.biff.DataValidation;
+import jxl.biff.DVParser;
 import jxl.biff.EmptyCell;
 import jxl.biff.FormattingRecords;
 import jxl.biff.FormulaData;
@@ -72,6 +73,7 @@ import jxl.write.DateTime;
 import jxl.write.Label;
 import jxl.write.Number;
 import jxl.write.WritableCell;
+import jxl.write.WritableCellFeatures;
 import jxl.write.WritableCellFormat;
 import jxl.write.WritableFont;
 import jxl.write.WritableHyperlink;
@@ -158,7 +160,8 @@ class WritableSheetImpl implements WritableSheet
   private boolean chartOnly;
 
   /**
-   * The data validations on this page
+   * The data validations on this page.  Used to store data validations
+   * from a read sheet
    */
   private DataValidation dataValidation;
 
@@ -712,7 +715,9 @@ class WritableSheetImpl implements WritableSheet
 
   /**
    * Inserts a blank column into this spreadsheet.  If the column is out of 
-   * range of the columns in the sheet, then no action is taken
+   * range of the columns in the sheet, then no action is taken.  If the 
+   * max column on the sheet has been reached, then the last column entry
+   * gets dropped
    *
    * @param col the column to insert
    */
@@ -1144,6 +1149,45 @@ class WritableSheetImpl implements WritableSheet
 
     int row = cell.getRow();
     RowRecord rowrec = getRowRecord(row);
+
+    CellValue curcell = rowrec.getCell(cv.getColumn());
+    boolean curSharedValidation = (curcell != null &&
+      curcell.getCellFeatures() != null &&
+      curcell.getCellFeatures().getDVParser() != null &&
+      curcell.getCellFeatures().getDVParser().extendedCellsValidation());
+
+    // Check for shared data validations, but only if the cell being added
+    // has a data validation
+    if (cell.getCellFeatures() != null &&
+        cell.getCellFeatures().hasDataValidation() && 
+        curSharedValidation)
+    {
+      DVParser dvp = curcell.getCellFeatures().getDVParser();
+      logger.warn("Cannot add cell at " + 
+                  CellReferenceHelper.getCellReference(cv) + 
+                  " because it is part of the shared cell validation group " +
+                  CellReferenceHelper.getCellReference(dvp.getFirstColumn(),
+                                                       dvp.getFirstRow()) +
+                  "-" +
+                  CellReferenceHelper.getCellReference(dvp.getLastColumn(),
+                                                       dvp.getLastRow()));
+      return;
+    }
+
+    // Apply any shared validation from the current cell to this cell
+    if (curSharedValidation)
+    {
+      WritableCellFeatures wcf = cell.getWritableCellFeatures();
+      
+      if (wcf == null)
+      {
+        wcf = new WritableCellFeatures();
+        cell.setCellFeatures(wcf);
+      }
+
+      wcf.shareDataValidation(curcell.getCellFeatures());
+    }
+
     rowrec.addCell(cv);
 
     // Adjust the max rows and max columns accordingly
@@ -1535,6 +1579,7 @@ class WritableSheetImpl implements WritableSheet
     si.setDrawings(drawings);
     si.setImages(images);
     si.setConditionalFormats(conditionalFormats);
+    si.setValidatedCells(validatedCells);
 
     si.copySheet();
 
@@ -1572,6 +1617,7 @@ class WritableSheetImpl implements WritableSheet
     sc.setPLSRecord(si.plsRecord);
     sc.setButtonPropertySetRecord(si.buttonPropertySet);
     sc.setHyperlinks(si.hyperlinks, hyperlinks);
+    sc.setValidatedCells(validatedCells);
 
     sc.copySheet();
 
@@ -2484,7 +2530,21 @@ class WritableSheetImpl implements WritableSheet
    */
   void removeDataValidation(CellValue cv)
   {
-    dataValidation.removeDataValidation(cv.getColumn(), cv.getRow());
+    if (dataValidation != null)
+    {
+      dataValidation.removeDataValidation(cv.getColumn(), cv.getRow());
+    }
+
+    if (validatedCells != null)
+    {
+      boolean result = validatedCells.remove(cv);
+
+      if (!result)
+      {
+        logger.warn("Could not remove validated cell " + 
+                    CellReferenceHelper.getCellReference(cv));
+      }
+    }
   }
 
   /**
@@ -2634,6 +2694,7 @@ class WritableSheetImpl implements WritableSheet
     si.setSheetWriter(sheetWriter);
     si.setDrawings(drawings);
     si.setImages(images);
+    si.setValidatedCells(validatedCells);
 
     si.importSheet();
 
@@ -2646,4 +2707,191 @@ class WritableSheetImpl implements WritableSheet
     maxRowOutlineLevel = si.getMaxRowOutlineLevel();
     maxColumnOutlineLevel = si.getMaxColumnOutlineLevel();
   }
+
+  /**
+   * Extend the data validation contained in the specified cell across and 
+   * downwards
+   *
+   * @param c the number of cells accross to apply this data validation
+   * @param r the number of cells downwards to apply this data validation
+   */
+  public void applySharedDataValidation(WritableCell c, 
+                                        int extraCols, 
+                                        int extraRows)
+    throws WriteException
+  {
+    // Check that the cell being applied has a data validation
+    if (c.getWritableCellFeatures() == null ||
+        !c.getWritableCellFeatures().hasDataValidation())
+    {
+      logger.warn("Cannot extend data validation for " +
+                  CellReferenceHelper.getCellReference(c.getColumn(), 
+                                                       c.getRow()) + 
+                  " as it has no data validation");
+      return;
+    }
+
+    // Check that none of the other cells in the range have any
+    // cell validations
+    int startColumn = c.getColumn();
+    int startRow = c.getRow();
+    int endRow = Math.min(numRows - 1, startRow + extraRows);
+    for (int y = startRow; y <= endRow; y++)
+    {
+      if (rows[y] != null)
+      {
+        int endCol = Math.min(rows[y].getMaxColumn() -1,
+                             startColumn + extraCols);
+        for (int x = startColumn; x <= endCol; x++)
+        {
+          // Ignore the first cell
+          if (x == startColumn && y == startRow)
+          {
+            continue; // continue statements - they're no better than gotos
+          }
+
+          WritableCell c2 = rows[y].getCell(x);
+
+          // Check that the target cell does not have any data validation
+          if (c2 != null &&
+              c2.getWritableCellFeatures() != null &&
+              c2.getWritableCellFeatures().hasDataValidation())
+          {
+            logger.warn("Cannot apply data validation from " +
+                        CellReferenceHelper.getCellReference(startColumn,
+                                                             startRow) +
+                        " to " + 
+                        CellReferenceHelper.getCellReference
+                          (startColumn + extraCols,
+                           startRow + extraRows) +
+                        " as cell " +
+                        CellReferenceHelper.getCellReference(x, y) +
+                        " already has a data validation");
+            return;
+          }
+        }
+      }
+    }
+
+    // Extend the range on the source data validation
+    WritableCellFeatures sourceDataValidation = c.getWritableCellFeatures();
+    sourceDataValidation.getDVParser().extendCellValidation(extraCols, 
+                                                            extraRows);
+
+    // Go through all the additional cells and add the data validation cell
+    for (int y = startRow; y <= startRow + extraRows; y++)
+    {
+      RowRecord rowrec = getRowRecord(y); // create the row if it doesn't exist
+      for (int x = startColumn; x <= startColumn + extraCols; x++)
+      {
+        // Ignore the first cell
+        if (x == startColumn && y == startRow)
+        {
+          continue; // continue statements - they're no better than gotos
+        }
+
+        WritableCell c2 = rowrec.getCell(x);
+        
+        // Check that the target cell does not have any data validation
+        if (c2 == null)
+        {
+          Blank b = new Blank(x, y);
+          WritableCellFeatures validation = new WritableCellFeatures();
+          validation.shareDataValidation(sourceDataValidation);
+          b.setCellFeatures(validation);
+          addCell(b);
+        }
+        else
+        {
+          // add the shared data validation to the existing cell
+          WritableCellFeatures validation = c2.getWritableCellFeatures();
+
+          if (validation != null)
+          {
+            validation.shareDataValidation(sourceDataValidation);
+          }
+          else
+          {
+            validation = new WritableCellFeatures();
+            validation.shareDataValidation(sourceDataValidation);
+            c2.setCellFeatures(validation);
+          }
+        }
+      }
+    }
+  }
+
+ /**
+   * Remove the shared data validation from multiple cells.  The cell passed 
+   * in is the top left cell.  The data validation is removed from this 
+   * cell and all cells which share the same validation.
+   *
+   * @param cell the top left cell containing the shared data validation
+   */
+  public void removeSharedDataValidation(WritableCell cell)
+    throws WriteException
+  {
+    WritableCellFeatures wcf = cell.getWritableCellFeatures();
+    if (wcf == null ||
+        !wcf.hasDataValidation())
+    {
+      return;
+    }
+
+    DVParser dvp = wcf.getDVParser();
+    
+    // If the cell is not part of an extended validation, then simply call
+    // the atomic remove validation from the cell features
+    if (!dvp.extendedCellsValidation())
+    {
+      wcf.removeDataValidation();
+      return;
+    }
+
+    // Check that the cell validation being removed is in the top left of the
+    // validated area
+    if (dvp.extendedCellsValidation())
+    {
+      if (cell.getColumn() != dvp.getFirstColumn() ||
+          cell.getRow() != dvp.getFirstRow())
+      {
+        logger.warn("Cannot remove data validation from " +
+                    CellReferenceHelper.getCellReference(dvp.getFirstColumn(),
+                                                         dvp.getFirstRow()) +
+                    "-" +
+                    CellReferenceHelper.getCellReference(dvp.getLastColumn(),
+                                                         dvp.getLastRow()) +
+                    " because the selected cell " +
+                    CellReferenceHelper.getCellReference(cell) +
+                    " is not the top left cell in the range");
+        return;
+      }
+    }
+
+    for (int y = dvp.getFirstRow(); y <= dvp.getLastRow(); y++)
+    {
+      for (int x = dvp.getFirstColumn(); x <= dvp.getLastColumn(); x++)
+      {
+        CellValue c2 = (CellValue) rows[y].getCell(x);
+        
+        // It's possible that some cells in the shared data range might
+        // be null eg. in the event of an insertRow or insertColumn
+        if (c2 != null)
+        {
+          c2.getWritableCellFeatures().removeSharedDataValidation();
+          c2.removeCellFeatures();
+        }
+      }
+    }
+
+    // Remove this shared validation from any data validations that were
+    // copied in
+    if (dataValidation != null)
+    {
+      dataValidation.removeSharedDataValidation(dvp.getFirstColumn(),
+                                                dvp.getFirstRow(),
+                                                dvp.getLastColumn(),
+                                                dvp.getLastRow());
+    }
+  }
 }
