@@ -26,8 +26,8 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
 
-import common.Assert;
-import common.Logger;
+import jxl.common.Assert;
+import jxl.common.Logger;
 
 import jxl.Range;
 import jxl.Sheet;
@@ -42,6 +42,7 @@ import jxl.biff.IndexMapping;
 import jxl.biff.IntegerHelper;
 import jxl.biff.RangeImpl;
 import jxl.biff.WorkbookMethods;
+import jxl.biff.XCTRecord;
 import jxl.biff.drawing.Drawing;
 import jxl.biff.drawing.DrawingGroup;
 import jxl.biff.drawing.DrawingGroupObject;
@@ -135,7 +136,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
   private DrawingGroup drawingGroup;
 
   /**
-   * The common workbook styles
+   * The jxl.common.workbook styles
    */
   private Styles styles;
 
@@ -161,6 +162,11 @@ public class WritableWorkbookImpl extends WritableWorkbook
    */
   private String[] addInFunctionNames;
 
+  /**
+   * The XCT records
+   */
+  private XCTRecord[] xctRecords;
+
   /**
    * Constructor.  Writes the workbook direct to the existing output stream
    * 
@@ -268,6 +274,9 @@ public class WritableWorkbookImpl extends WritableWorkbook
     // Copy any add in functions
     addInFunctionNames = wp.getAddInFunctionNames();
 
+    // Copy XCT records
+    xctRecords = wp.getXCTRecords();
+
     // Copy any external sheets
     if (wp.getExternalSheetRecord() != null)
     {
@@ -696,6 +705,15 @@ public class WritableWorkbookImpl extends WritableWorkbook
     BOFRecord bof = new BOFRecord(BOFRecord.workbookGlobals);
     outputFile.write(bof);
 
+    // Must immediatly follow the BOF record
+    if (settings.getTemplate())
+    {
+      // Only write record if we are a template
+      TemplateRecord trec= new TemplateRecord();
+      outputFile.write(trec);
+    }
+
+
     InterfaceHeaderRecord ihr = new InterfaceHeaderRecord();
     outputFile.write(ihr);
 
@@ -705,7 +723,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     InterfaceEndRecord ier = new InterfaceEndRecord();
     outputFile.write(ier);
 
-    WriteAccessRecord wr = new WriteAccessRecord();
+    WriteAccessRecord wr = new WriteAccessRecord(settings.getWriteAccess());
     outputFile.write(wr);
 
     CodepageRecord cp = new CodepageRecord();
@@ -714,6 +732,14 @@ public class WritableWorkbookImpl extends WritableWorkbook
     DSFRecord dsf = new DSFRecord();
     outputFile.write(dsf);
 
+    if (settings.getExcel9File())
+    {
+      // Only write record if we are a template
+      // We are not excel 2000, should we still set the flag
+      Excel9FileRecord e9rec= new Excel9FileRecord();
+      outputFile.write(e9rec);
+    }
+
     TabIdRecord tabid = new TabIdRecord(getNumberOfSheets());
     outputFile.write(tabid);
 
@@ -732,7 +758,8 @@ public class WritableWorkbookImpl extends WritableWorkbook
     outputFile.write(fgcr);
 
     // do not support password protected workbooks
-    WindowProtectRecord wpr = new WindowProtectRecord(false);
+    WindowProtectRecord wpr = new WindowProtectRecord
+      (settings.getWindowProtected());
     outputFile.write(wpr);
 
     ProtectRecord pr = new ProtectRecord(wbProtected);
@@ -775,7 +802,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     BackupRecord bkr = new BackupRecord(false);
     outputFile.write(bkr);
 
-    HideobjRecord ho = new HideobjRecord(false);
+    HideobjRecord ho = new HideobjRecord(settings.getHideobj());
     outputFile.write(ho);
     
     NineteenFourRecord nf = new NineteenFourRecord(false);
@@ -784,7 +811,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     PrecisionRecord pc = new PrecisionRecord(false);
     outputFile.write(pc);
 
-    RefreshAllRecord rar = new RefreshAllRecord(false);
+    RefreshAllRecord rar = new RefreshAllRecord(settings.getRefreshAll());
     outputFile.write(rar);
 
     BookboolRecord bb = new BookboolRecord(true);
@@ -858,8 +885,8 @@ public class WritableWorkbookImpl extends WritableWorkbook
     if (addInFunctionNames != null && addInFunctionNames.length > 0)
     {
       // Write out the supbook record
-      SupbookRecord supbook = new SupbookRecord();
-      outputFile.write(supbook);
+      //      SupbookRecord supbook = new SupbookRecord();
+      //      outputFile.write(supbook);
 
       for (int i = 0 ; i < addInFunctionNames.length; i++)
       {
@@ -868,6 +895,14 @@ public class WritableWorkbookImpl extends WritableWorkbook
       }
     }
 
+    if (xctRecords != null)
+    {
+      for (int i = 0 ; i < xctRecords.length; i++)
+      {
+        outputFile.write(xctRecords[i]);
+      }
+    }
+
     // Write out the external sheet record, if it exists
     if (externSheet != null)
     {
@@ -1045,6 +1080,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     }
     
     // An unknown supbook - return unkown
+    logger.warn("Unknown Supbook 1");
     return "[UNKNOWN]";
   }
 
@@ -1074,6 +1110,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     }
     
     // An unknown supbook - return unkown
+    logger.warn("Unknown Supbook 2");
     return "[UNKNOWN]";
   }
 
@@ -1185,6 +1222,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
     if (closeSquareBracketsIndex == -1 ||
         openSquareBracketsIndex == -1)
     {
+      logger.warn("Square brackets");
       return -1;
     }
 
@@ -1651,7 +1689,7 @@ public class WritableWorkbookImpl extends WritableWorkbook
   }
 
   /**
-   * Accessor for the common styles
+   * Accessor for the jxl.common.styles
    *
    * @return the standard styles for this workbook
    */
